Ectatomma Ruidum Roger; (c) A. Drogoul, S. Lalande, B. Corbara, D. Fresneau 1996
Date: 30/10/95 - 23/02/96; Version of Manta: 2.0b1

This file describes the biological parameters used to model
Ectatomma Ruidum Roger ants. These parameters are intented
to be used by the agents during the simulation.


species Ectatomma Ruidum Roger {polygyny false}



graphics AGENTS40.BMP {size 40}
	{       worker 8
	 	worker+larva 8
	 	worker+egg 8
	 	worker+cocon 8
	 	worker+food 8
	 	queen 8
	 	queen+larva 8
	 	queen+egg 8
	 	queen+cocoon 8
	 	queen+food 8
		cocoon 1
		egg 1
		larva 1}

	
class AntClass {system TMovingAgent type worker}
	
	var lifeTime {min 0 max 6000000 init 0 delta 0 increment 1}	
	var foodLevel {min 3 max 30 init 16 delta 2 increment -0.002}		
	var cureLevel {min 0 max 30 init 15 delta 0 increment -0.002}
	var carryingCapacity {value 15}

	stim kill_egg {range internal type threshold}
		{if ((value[foodLevel] < (init[foodLevel] / 3)) & (stim[loc_egg] > 0))
		then 1000 else 0}
	stim kill_larva {range internal type threshold}
		{if ((value[foodLevel] < (init[foodLevel] / 3)) & (stim[loc_larva] > 0))
		then 500 else 0}
	stim cure_self {range internal type normal}
		{value (init[cureLevel] - value[cureLevel])}
	stim hungry_self {range internal type threshold}
		{if (value[foodLevel] < (init[foodLevel] / 3))
		then 100 else ((init[foodLevel] - value[foodLevel]) * 2)}
	stim maturing_self {range internal type threshold}
		{if ((value[foodLevel] = 0) | (value[cureLevel] = 0) | (value[lifeTime] = max[lifeTime]))
		then 1000 else 0}
	
	task move_egg {weight 4 threshold 15}
		{repeat follow(move_egg)
		do carry(move_egg)
		repeat follow(move_egg humidity -move_larva)
		stop putDown(egg)}
	task move_larva {weight 4 threshold 15} 
		{repeat follow(move_larva)
		do carry(move_larva)
		repeat follow(-move_egg humidity move_larva -light)
		stop putDown(larva)}
	task move_cocoon {weight 4 threshold 15} 
		{repeat follow(move_cocoon)
		do carry(move_cocoon)
		repeat follow(move_cocoon -humidity -light)
		stop putDown(cocoon)}
	task cure_larva {weight 16 threshold 60}
		{repeat follow(cure_larva)
		repeat cure(cure_larva)}
	task cure_egg {weight 8 threshold 30}
		{repeat follow(cure_egg)
		repeat cure(cure_egg)}
	task cure_cocoon {weight 48 threshold 180}
		{repeat follow(cure_cocoon)
		repeat cure(cure_cocoon)}
	task cure_self {weight 8 threshold 30}
		{repeat cure()}
	task hungry_larva {weight 4 threshold 15}
		{repeat follow(loc_food food)
		do carryOne(food)
		repeat follow(hungry_larva humidity)
		stop putDown(food)}
	task hungry_self {weight 2 threshold 15 weightIncrement 0 thresholdIncrement 0}
		{repeat follow(loc_food food)
		repeat eat(food)}
	task kill_egg {weight 4 threshold 15 weightIncrement 0 thresholdIncrement 0}
		{repeat follow(loc_egg)
		do kill(egg)}
	task kill_larva {weight 10 threshold 20 weightIncrement 0 thresholdIncrement 0}
		{repeat follow(loc_larva hungry_larva)
		do kill(larva)}
	task default {weight 1 threshold 0 weightIncrement 0 thresholdIncrement 0}
		{repeat move()}
	task food {weight 4 threshold 100 weightIncrement 0 thresholdIncrement 0}
		{repeat follow(food)
		repeat eat(food)
		do carryOne(food)
		repeat follow(humidity)
		stop putDown()}
	task light {weight 0.75 threshold 10 weightIncrement -0.1 thresholdIncrement 0}
		{repeat follow(humidity -light)}
	task maturing_self {weight 4 threshold 10}
		{do mature()}
	task maturing_egg {weight 4 threshold 15}
		{repeat follow(maturing_egg)
		do carry(maturing_egg)
		repeat follow(humidity larva -light)
		stop putDown()}
	task maturing_larva {weight 4 threshold 15}
		{repeat follow(maturing_larva)
		do carry(maturing_larva)
		repeat follow(-larva cocoon -humidity)
		stop putDown()}
	task maturing_cocoon {weight 4 threshold 15}
		{repeat follow(maturing_cocoon)
		repeat cure(maturing_cocoon)}
		
endClass AntClass

------------------------------------------------------------------
class QueenClass 
	{system TReproductiveAgent 
	type queen 
	extends AntClass
	gives EggClass}

	var foodLevel {min 3 max 30 init 16 delta 2 increment -0.0025}		
	var reproducingInterval {min 0 max 6776 init 6776 delta 100 increment -1}

	stim layEggs_queen {range internal type threshold}
		{if ((value[reproducingInterval] = 0) & (value[foodLevel] > 4))
		then 1000 else 0}

	task layEggs_queen {weight 100 threshold 0}
		{repeat follow(humidity move_egg cure_egg)
		stop reproduce()}
	task light {weight 0.75 threshold 10 weightIncrement -0.05 thresholdIncrement 0}
		{repeat follow(humidity -light)}

endClass QueenClass

class EggClass {system TBroodAgent type egg next LarvaClass}

	var lifeTime {min 0 max 253440 init 0 delta 3840 increment 1}
	var cureLevel {min 0 max 30 init 15 delta 1 increment -0.003}

	stim loc_egg {range external type fixed}
		{value 1}
	stim move_egg {range external type increment}
		{step (0.05 / stim[humidity]) + (0.003 * stim[light])
		min 0.001 max 0.1}
	stim cure_egg {range external type normal}
		{value (init[cureLevel] - value[cureLevel])}
	stim maturing_egg {range external type threshold}
		{if ((value[cureLevel] = 0)  | (value[lifeTime] = max[lifeTime]))
		then 5 else 0}

	task maturing_egg {weight 4 threshold 10}
		{do mature()}
 endClass EggClass

------------------------------------------------------------------
class LarvaClass {system TBroodAgent type larva next CocoonClass}
	var lifeTime {min 0 max 212428 init 0 delta 11520 increment 1}
	var foodLevel {min 0 max 30 init 16 delta 1 increment -0.002}
	var cureLevel {min 0 max 30 init 15 delta 1 increment -0.002}

	stim loc_larva {range external type fixed}
		{value 1}
	stim move_larva {range external type increment}
		{step ((0.05 / stim[humidity]) + (0.003 * stim[light]))
		min 0.001 max 0.1}
	stim hungry_larva {range external type threshold}
		{if (value[foodLevel] < (init[foodLevel] / 3))
		then 100 else ((init[foodLevel] - value[foodLevel]) * 2)}
	stim cure_larva {range external type normal}
		{value (init[cureLevel] - value[cureLevel])}
	stim maturing_larva {range external type threshold}
		{if ((value[foodLevel] = 0) | (value[cureLevel] = 0) | (value[lifeTime] = max[lifeTime]))
		then 5 else 0}

	task maturing_larva {weight 4 threshold 10}
		{do mature()}

	task hungry_larva {weight 4 threshold 4 weightIncrement 0 thresholdIncrement 0}
		{repeat eat(food)}

endClass LarvaClass

class CocoonClass {system TBroodAgent type cocoon next AntClass}

	var lifeTime {min 0 max 334080 delta 46080 init 0 increment 1}
	var cureLevel {min 0 max 30 init 25 increment -0.0005}

	stim move_cocoon {range external type increment}
		{step ((0.001 * stim[humidity]) + (0.003 * stim[light]))
		min 0.001 max 0.1}
	stim cure_cocoon {range external type normal}
		{value (init[cureLevel] - value[cureLevel])}
	
	stim maturing_cocoon {range external type threshold}
		{if ((value[cureLevel] = 0) | (value[lifeTime] = max[lifeTime]))
		then 5 else 0}

        task maturing_cocoon {weight 4 threshold 10}
		{do mature()}

